Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(762)

Unified Diff: chrome/browser/chromeos/arc/arc_optin_uma.h

Issue 2785813002: arc: Provide UMA for OptIn flow. (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/arc/arc_optin_uma.h
diff --git a/chrome/browser/chromeos/arc/arc_optin_uma.h b/chrome/browser/chromeos/arc/arc_optin_uma.h
index c0aee1e5e7de25c242d00cd86b0fa72abd636979..5f0349aefe7f4378094620f7c2092fc68ac4c271 100644
--- a/chrome/browser/chromeos/arc/arc_optin_uma.h
+++ b/chrome/browser/chromeos/arc/arc_optin_uma.h
@@ -28,15 +28,23 @@ enum class OptInActionType : int {
};
enum class OptInCancelReason {
- USER_CANCEL = 0, // Canceled by user.
- UNKNOWN_ERROR = 1, // Unclassified failure.
- NETWORK_ERROR = 2, // Network failure.
- SERVICE_UNAVAILABLE = 3, // GMS Services are not available.
+ // Canceled by user.
Luis Héctor Chávez 2017/03/30 15:49:25 The formatting for this enum looks different from
khmel 2017/03/30 17:01:43 Done.
+ USER_CANCEL = 0,
+ // Unclassified failure.
+ UNKNOWN_ERROR = 1,
+ // Network failure.
+ NETWORK_ERROR = 2,
+ DEPRECATED_SERVICE_UNAVAILABLE = 3,
DEPRECATED_BAD_AUTHENTICATION = 4,
DEPRECATED_GMS_CORE_NOT_AVAILABLE = 5,
- CLOUD_PROVISION_FLOW_FAIL = 6, // Cloud provision flow failed.
- ANDROID_MANAGEMENT_REQUIRED = 7, // Android management is required for user.
- SIZE, // The size of this enum; keep last.
+ // Cloud provision flow failed.
+ CLOUD_PROVISION_FLOW_FAIL = 6,
+ // Android management is required for user.
+ ANDROID_MANAGEMENT_REQUIRED = 7,
+ // Cannot start ARC because it is busy.
+ SESSION_BUSY = 8,
+ // The size of this enum; keep last.
+ SIZE,
};
enum class OptInSilentAuthCode {
@@ -121,8 +129,29 @@ enum class ProvisioningResult : int {
SIZE,
};
+enum class OptInFlowResult : int {
+ // OptIn has been started.
Luis Héctor Chávez 2017/03/30 15:49:25 nit: s/has been/has/
khmel 2017/03/30 17:01:43 Done.
+ STARTED = 0,
+
+ // OptIn has been succeeded, this also includes succeeded with error cases.
+ SUCCEEDED = 1,
+
+ // OptIn has been succeeded but with retry after an error.
+ SUCCEEDED_AFTER_RETRY = 2,
+
+ // OptIn has been canceled, this also includes canceled after error cases.
+ CANCELED = 3,
+
+ // OptIn has been canceled after an error was reported.
+ CANCELED_AFTER_ERROR = 4,
+
+ // The size of this enum; keep last.
+ SIZE,
+};
+
void UpdateOptInActionUMA(OptInActionType type);
void UpdateOptInCancelUMA(OptInCancelReason reason);
+void UpdateOptInFlowResultUMA(OptInFlowResult result);
void UpdateEnabledStateUMA(bool enabled);
void UpdateProvisioningResultUMA(ProvisioningResult result, bool managed);
void UpdateProvisioningTiming(const base::TimeDelta& elapsed_time,
« no previous file with comments | « no previous file | chrome/browser/chromeos/arc/arc_optin_uma.cc » ('j') | chrome/browser/chromeos/arc/arc_session_manager.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698